"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var fs = tslib_1.__importStar(require("fs-extra"));
var klaw_1 = tslib_1.__importDefault(require("klaw"));
var shelljs_1 = require("shelljs");
var yargs = tslib_1.__importStar(require("yargs"));
tslib_1.__exportStar(require("./changelog"), exports);
tslib_1.__exportStar(require("./generate"), exports);
tslib_1.__exportStar(require("./migrate"), exports);
var Files;
(function (Files) {
    Files["gitignore"] = ".gitignore";
    Files["miskTab"] = "miskTab.json";
    Files["old"] = ".old_build_files";
    Files["package"] = "package.json";
    Files["packageLock"] = "package-lock.json";
    Files["prettier"] = "prettier.config.js";
    Files["tsconfig"] = "tsconfig.json";
    Files["tslint"] = "tslint.json";
    Files["webpack"] = "webpack.config.js";
    Files["yarnLock"] = "yarn.lock";
})(Files = exports.Files || (exports.Files = {}));
exports.JsonOptions = { spaces: 2 };
exports.logFormatter = function (tag, msg, dir) {
    if (dir === void 0) { dir = shelljs_1.pwd().stdout; }
    return "[" + tag.toUpperCase() + "][" + dir
        .split("/")
        .pop()
        .toUpperCase() + "] " + msg;
};
exports.logDebug = function (tag, msg, dir) {
    if (dir === void 0) { dir = shelljs_1.pwd().stdout; }
    return console.log(exports.logFormatter(tag, msg, dir));
};
exports.path = function () {
    var segments = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        segments[_i] = arguments[_i];
    }
    return "" + segments.join("/");
};
exports.parseArgs = function () {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    return ({
        args: args,
        dir: args[0] ? args[0] : shelljs_1.pwd().stdout
    });
};
exports.remove = function (path) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    return tslib_1.__generator(this, function (_a) {
        try {
            fs.remove(path);
        }
        catch (e) {
            console.log("[ERROR] " + e);
        }
        return [2];
    });
}); };
exports.execute = function (cmd) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    var dir = exports.parseArgs.apply(void 0, args).dir;
    shelljs_1.cd(dir);
    var terminal = shelljs_1.exec(cmd);
    terminal.stdout;
    if (terminal.code) {
        throw new Error("Shell command `" + cmd + "` exited with code " + terminal.code + ". " + terminal.stderr);
    }
};
exports.npmRunScript = function (cmd, prebuild) {
    if (prebuild === void 0) { prebuild = false; }
    return (prebuild ? "miskweb prebuild && " : "") + "npm run-script " + cmd;
};
exports.handleCommand = function (args, handlerFn, blockedOptions) {
    if (blockedOptions === void 0) { blockedOptions = []; }
    return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var invalidOptions, tabs_1;
        var _this = this;
        return tslib_1.__generator(this, function (_a) {
            invalidOptions = [];
            blockedOptions.map(function (opt) {
                if (opt in args) {
                    invalidOptions.push(opt);
                }
            });
            if (invalidOptions.length > 0) {
                console.error("Invalid use of " + invalidOptions.map(function (opt) { return "-" + opt + " "; }) + " option with command " + args._[0] + ".");
                yargs
                    .hide(invalidOptions[0])
                    .hide("help")
                    .hide("version")
                    .showHelp();
            }
            else if (args.each) {
                tabs_1 = [];
                klaw_1.default(".")
                    .on("data", function (item) {
                    if (item.stats.isFile() && item.path.includes("/miskTab.json")) {
                        tabs_1.push(item.path.split("/miskTab.json")[0]);
                    }
                })
                    .on("error", function (err) { return console.error(err); })
                    .on("end", function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                    var tab;
                    return tslib_1.__generator(this, function (_a) {
                        for (tab in tabs_1) {
                            shelljs_1.cd(tabs_1[tab]);
                            handlerFn(tabs_1[tab]);
                        }
                        return [2];
                    });
                }); });
            }
            else {
                handlerFn();
            }
            return [2];
        });
    });
};
//# sourceMappingURL=index.js.map