"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var reduce_1 = tslib_1.__importDefault(require("lodash/reduce"));
var utils_1 = require("../../utils");
var templates_1 = require("../templates");
var changelog_1 = require("../changelog");
var header = {
    license: "SEE LICENSE IN https://github.com/square/misk-web",
    main: "src/index.tsx"
};
var scripts = function (miskTab) { return ({
    engines: {
        yarn: "YARN NO LONGER USED - use npm instead."
    },
    scripts: {
        build: "npm run-script lib " + (miskTab.zipOnBuild ? "&& npm run-script zip" : ""),
        "ci-build": "npm install && npm run-script clean && npm run-script prebuild && cross-env NODE_ENV=production npm run-script lib " + (miskTab.zipOnBuild ? "&& npm run-script zip" : ""),
        "dev-build": "npm run-script dev-lib " + (miskTab.zipOnBuild ? "&& npm run-script zip" : ""),
        clean: "rm -rf demo lib",
        "clean-build-files": "rm .hash package-lock.json package.json tsconfig.json tslint.json webpack.config.js",
        lib: "cross-env NODE_ENV=production webpack",
        "dev-lib": "cross-env NODE_ENV=development webpack",
        lint: 'prettier --write --config package.json ".{/src/**/,/}*.{md,css,sass,less,json,js,jsx,ts,tsx}"',
        prebuild: "npm run-script lint",
        reinstall: "rm -rf node_modules && npm run-script install",
        start: "npm run-script prebuild && cross-env NODE_ENV=development webpack-dev-server",
        test: "echo no test",
        zip: "tar " + [
            utils_1.Files.gitignore,
            utils_1.Files.old,
            utils_1.Files.package,
            utils_1.Files.packageLock,
            utils_1.Files.prettier,
            utils_1.Files.tsconfig,
            utils_1.Files.tslint,
            utils_1.Files.webpack,
            utils_1.Files.yarnLock,
            "demo",
            "lib",
            ".DS_Store",
            "*.log",
            "node_modules",
            miskTab.slug + ".tgz"
        ]
            .map(function (file) { return "--exclude='" + file + "'"; })
            .join(" ") + " -czvf " + miskTab.slug + ".tgz ./"
    }
}); };
var createMiskPackageJson = function (packages, miskTab) {
    return reduce_1.default(packages, function (packageJson, pkg) {
        var _a;
        var pkgVersion = changelog_1.getPackageVersion(pkg, miskTab.version);
        if (pkgVersion) {
            return tslib_1.__assign({}, packageJson, (_a = {}, _a[pkg] = pkgVersion, _a));
        }
        else {
            console.error(utils_1.logFormatter("prebuild][error", "Failed to find package " + pkg + "@" + miskTab.version + ".\n\tTry updating your version in miskTab.json to latest: " + changelog_1.MiskVersion.latest + "."));
            return packageJson;
        }
    }, {});
};
var dependencies = function (miskTab, pkg) { return ({
    dependencies: tslib_1.__assign({}, pkg.dependencies, createMiskPackageJson([changelog_1.MiskPkg.common, changelog_1.MiskPkg.core, changelog_1.MiskPkg.simpleredux], miskTab))
}); };
var devDependencies = function (miskTab, pkg) { return ({
    devDependencies: tslib_1.__assign({}, pkg.devDependencies, createMiskPackageJson([changelog_1.MiskPkg.dev, changelog_1.MiskPkg.tslint], miskTab))
}); };
exports.createPackage = function (miskTab, pkg) { return (tslib_1.__assign({ name: "misk-web-tab-" + miskTab.slug, version: pkg.version && pkg.version.length > 0
        ? pkg.version
        : utils_1.getVersion(miskTab.version) }, header, scripts(miskTab), dependencies(miskTab, pkg), devDependencies(miskTab, pkg), templates_1.prettier, { generated: templates_1.generatedByCLI })); };
//# sourceMappingURL=package.js.map